==> jc-1.4.0.tar.gz: java/awt/geom/Point2D__24Double.h <==
// public class java.awt.geom.Point2D$Double

// class file dependencies
// @dep_class 7b4d9094dbdc54ce java_awt_geom_Point2D
// @dep_class 4cac574c235eb564 java_awt_geom_Point2D__24Double
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_geom_Point2D

#include "java/awt/geom/Point2D.h"

#ifndef _JC_java_awt_geom_Point2D__24Double_H_
#define _JC_java_awt_geom_Point2D__24Double_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_geom_Point2D__24Double$sub_refs	_jc_java_awt_geom_Point2D__24Double$sub_refs;
typedef struct _jc_java_awt_geom_Point2D__24Double$sub_nonrefs	_jc_java_awt_geom_Point2D__24Double$sub_nonrefs;
typedef struct _jc_java_awt_geom_Point2D__24Double$refs	_jc_java_awt_geom_Point2D__24Double$refs;
typedef struct _jc_java_awt_geom_Point2D__24Double$nonrefs	_jc_java_awt_geom_Point2D__24Double$nonrefs;
typedef struct _jc_java_awt_geom_Point2D__24Double$object	_jc_java_awt_geom_Point2D__24Double$object;

typedef const struct _jc_java_awt_geom_Point2D__24Double$vmethods	_jc_java_awt_geom_Point2D__24Double$vmethods;
typedef const struct _jc_java_awt_geom_Point2D__24Double$vtable	_jc_java_awt_geom_Point2D__24Double$vtable;
typedef const struct _jc_java_awt_geom_Point2D__24Double$vtype	_jc_java_awt_geom_Point2D__24Double$vtype;

// Constructors
extern void _jc_java_awt_geom_Point2D__24Double$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_geom_Point2D__24Double$object *);
extern void _jc_java_awt_geom_Point2D__24Double$method$_init$89340f7ed2ac6878(_jc_env *, struct _jc_java_awt_geom_Point2D__24Double$object *, jdouble, jdouble);

// Virtual methods
extern jdouble _jc_java_awt_geom_Point2D__24Double$method$getX$da8367f71985b05b(_jc_env *, struct _jc_java_awt_geom_Point2D__24Double$object *);
extern jdouble _jc_java_awt_geom_Point2D__24Double$method$getY$cea2a8c824df48e5(_jc_env *, struct _jc_java_awt_geom_Point2D__24Double$object *);
extern void _jc_java_awt_geom_Point2D__24Double$method$setLocation$689557087e3caf93(_jc_env *, struct _jc_java_awt_geom_Point2D__24Double$object *, jdouble, jdouble);
extern struct _jc_java_lang_String$object *_jc_java_awt_geom_Point2D__24Double$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_awt_geom_Point2D__24Double$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_geom_Point2D__24Double$method_info$getX$da8367f71985b05b;
extern _jc_method _jc_java_awt_geom_Point2D__24Double$method_info$getY$cea2a8c824df48e5;
extern _jc_method _jc_java_awt_geom_Point2D__24Double$method_info$setLocation$689557087e3caf93;
extern _jc_method _jc_java_awt_geom_Point2D__24Double$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_awt_geom_Point2D__24Double$vmethods {
	jdouble	(*getX$da8367f71985b05b)(_jc_env *, struct _jc_java_awt_geom_Point2D__24Double$object *);
	jdouble	(*getY$cea2a8c824df48e5)(_jc_env *, struct _jc_java_awt_geom_Point2D__24Double$object *);
	void	(*setLocation$689557087e3caf93)(_jc_env *, struct _jc_java_awt_geom_Point2D__24Double$object *, jdouble, jdouble);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_awt_geom_Point2D__24Double$object *);
};

// Vtable
struct _jc_java_awt_geom_Point2D__24Double$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_geom_Point2D$vmethods	java_awt_geom_Point2D;
	_jc_java_awt_geom_Point2D__24Double$vmethods	java_awt_geom_Point2D__24Double;
};

// Vtype
struct _jc_java_awt_geom_Point2D__24Double$vtype {
	_jc_type			type;
	_jc_java_awt_geom_Point2D__24Double$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_geom_Point2D__24Double$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_geom_Point2D__24Double$refs {
    _jc_java_awt_geom_Point2D__24Double$sub_refs	java_awt_geom_Point2D__24Double;
    _jc_java_awt_geom_Point2D$sub_refs	java_awt_geom_Point2D;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_geom_Point2D__24Double$sub_nonrefs {
	jdouble	x;
	jdouble	y;
};

// Non-reference instance fields (object)
struct _jc_java_awt_geom_Point2D__24Double$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_geom_Point2D$sub_nonrefs	java_awt_geom_Point2D;
    _jc_java_awt_geom_Point2D__24Double$sub_nonrefs	java_awt_geom_Point2D__24Double;
};

// Object instance structure
struct _jc_java_awt_geom_Point2D__24Double$object {
	_jc_java_awt_geom_Point2D__24Double$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_geom_Point2D__24Double$vtype	*vtype;
	_jc_java_awt_geom_Point2D__24Double$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_geom_Point2D__24Double$vtype _jc_java_awt_geom_Point2D__24Double$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_geom_Point2D__24Double, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_geom_Point2D__24Double$class_object;

#endif	/* _JC_java_awt_geom_Point2D__24Double_H_ */

==> jc-1.4.6.tar.gz: java/awt/geom/Point2D__24Double.h <==
// public class java.awt.geom.Point2D$Double

// class file dependencies
// @dep_class 7b4d9094dbdc54ce java_awt_geom_Point2D
// @dep_class 4cac574c235eb564 java_awt_geom_Point2D__24Double
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_geom_Point2D

#include "java/awt/geom/Point2D.h"

#ifndef _JC_java_awt_geom_Point2D__24Double_H_
#define _JC_java_awt_geom_Point2D__24Double_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_geom_Point2D__24Double$sub_refs	_jc_java_awt_geom_Point2D__24Double$sub_refs;
typedef struct _jc_java_awt_geom_Point2D__24Double$sub_nonrefs	_jc_java_awt_geom_Point2D__24Double$sub_nonrefs;
typedef struct _jc_java_awt_geom_Point2D__24Double$refs	_jc_java_awt_geom_Point2D__24Double$refs;
typedef struct _jc_java_awt_geom_Point2D__24Double$nonrefs	_jc_java_awt_geom_Point2D__24Double$nonrefs;
typedef struct _jc_java_awt_geom_Point2D__24Double$object	_jc_java_awt_geom_Point2D__24Double$object;

typedef const struct _jc_java_awt_geom_Point2D__24Double$vmethods	_jc_java_awt_geom_Point2D__24Double$vmethods;
typedef const struct _jc_java_awt_geom_Point2D__24Double$vtable	_jc_java_awt_geom_Point2D__24Double$vtable;
typedef const struct _jc_java_awt_geom_Point2D__24Double$vtype	_jc_java_awt_geom_Point2D__24Double$vtype;

// Constructors
extern void _jc_java_awt_geom_Point2D__24Double$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_geom_Point2D__24Double$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_geom_Point2D__24Double$method$_init$89340f7ed2ac6878(_jc_env *, struct _jc_java_awt_geom_Point2D__24Double$object *, jdouble, jdouble) _JC_JCNI_ATTR;

// Virtual methods
extern jdouble _jc_java_awt_geom_Point2D__24Double$method$getX$da8367f71985b05b(_jc_env *, struct _jc_java_awt_geom_Point2D__24Double$object *) _JC_JCNI_ATTR;
extern jdouble _jc_java_awt_geom_Point2D__24Double$method$getY$cea2a8c824df48e5(_jc_env *, struct _jc_java_awt_geom_Point2D__24Double$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_geom_Point2D__24Double$method$setLocation$689557087e3caf93(_jc_env *, struct _jc_java_awt_geom_Point2D__24Double$object *, jdouble, jdouble) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_awt_geom_Point2D__24Double$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_awt_geom_Point2D__24Double$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_geom_Point2D__24Double$method_info$getX$da8367f71985b05b;
extern _jc_method _jc_java_awt_geom_Point2D__24Double$method_info$getY$cea2a8c824df48e5;
extern _jc_method _jc_java_awt_geom_Point2D__24Double$method_info$setLocation$689557087e3caf93;
extern _jc_method _jc_java_awt_geom_Point2D__24Double$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_awt_geom_Point2D__24Double$vmethods {
	jdouble	(*getX$da8367f71985b05b)(_jc_env *, struct _jc_java_awt_geom_Point2D__24Double$object *) _JC_JCNI_ATTR;
	jdouble	(*getY$cea2a8c824df48e5)(_jc_env *, struct _jc_java_awt_geom_Point2D__24Double$object *) _JC_JCNI_ATTR;
	void	(*setLocation$689557087e3caf93)(_jc_env *, struct _jc_java_awt_geom_Point2D__24Double$object *, jdouble, jdouble) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_awt_geom_Point2D__24Double$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_geom_Point2D__24Double$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_geom_Point2D$vmethods	java_awt_geom_Point2D;
	_jc_java_awt_geom_Point2D__24Double$vmethods	java_awt_geom_Point2D__24Double;
};

// Vtype
struct _jc_java_awt_geom_Point2D__24Double$vtype {
	_jc_type			type;
	_jc_java_awt_geom_Point2D__24Double$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_geom_Point2D__24Double$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_geom_Point2D__24Double$refs {
    _jc_java_awt_geom_Point2D__24Double$sub_refs	java_awt_geom_Point2D__24Double;
    _jc_java_awt_geom_Point2D$sub_refs	java_awt_geom_Point2D;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_geom_Point2D__24Double$sub_nonrefs {
	jdouble	x;
	jdouble	y;
};

// Non-reference instance fields (object)
struct _jc_java_awt_geom_Point2D__24Double$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_geom_Point2D$sub_nonrefs	java_awt_geom_Point2D;
    _jc_java_awt_geom_Point2D__24Double$sub_nonrefs	java_awt_geom_Point2D__24Double;
};

// Object instance structure
struct _jc_java_awt_geom_Point2D__24Double$object {
	_jc_java_awt_geom_Point2D__24Double$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_geom_Point2D__24Double$vtype	*vtype;
	_jc_java_awt_geom_Point2D__24Double$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_geom_Point2D__24Double$vtype _jc_java_awt_geom_Point2D__24Double$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_geom_Point2D__24Double, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_geom_Point2D__24Double$class_object;

#endif	/* _JC_java_awt_geom_Point2D__24Double_H_ */
